@@ -110,7 +110,11 @@ def find_datetime_in_line(line):
     try:
         return re.findall(r"\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d{6}\+\d{4}", line)[0]
     except Exception:
-        return None
+        try:
+            # find like: 2022-11-14 09:32:14.791000+0800
+            return re.findall(r"\d{4}-\d{2}-\d{2}\s\d{2}:\d{2}:\d{2}\.\d{6}\+\d{4}", line)[0]
+        except Exception:
+            return None
 
 
 def find_voltage_in_line(line):
